@@ -9,7 +9,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2014-2015 Kenneth J. Pronovici.
+# Copyright (c) 2014-2016 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -85,13 +85,15 @@ Testing XML Extraction
 
 # System modules
 import unittest
+import tempfile
 
 # Cedar Backup modules
 from CedarBackup2.util import UNIT_BYTES, UNIT_MBYTES, UNIT_GBYTES
 from CedarBackup2.config import ByteQuantity
-from CedarBackup2.testutil import findResources, failUnlessAssignRaises
+from CedarBackup2.testutil import findResources, buildPath, removedir, extractTar, failUnlessAssignRaises
 from CedarBackup2.xmlutil import createOutputDom, serializeDom
 from CedarBackup2.extend.amazons3 import LocalConfig, AmazonS3Config
+from CedarBackup2.tools.amazons3 import _buildSourceFiles, _checkSourceFiles
 
 
 #######################################################################
@@ -100,8 +102,9 @@ from CedarBackup2.extend.amazons3 import LocalConfig, AmazonS3Config
 
 DATA_DIRS = [ "./data", "./testcase/data", ]
 RESOURCES = [ "amazons3.conf.1", "amazons3.conf.2", "amazons3.conf.3", "tree1.tar.gz",
-              "tree2.tar.gz", "tree8.tar.gz", "tree15.tar.gz", "tree16.tar.gz",
-              "tree17.tar.gz", "tree18.tar.gz", "tree19.tar.gz", "tree20.tar.gz", ]
+              "tree2.tar.gz", "tree4.tar.gz", "tree8.tar.gz", "tree13.tar.gz",
+              "tree15.tar.gz", "tree16.tar.gz", "tree17.tar.gz", "tree18.tar.gz",
+              "tree19.tar.gz", "tree20.tar.gz", ]
 
 
 #######################################################################
@@ -175,7 +178,6 @@ class TestAmazonS3Config(unittest.TestCase):
       amazons3.warnMidnite = False
       self.failUnlessEqual(False, amazons3.warnMidnite)
 
-   #pylint: disable=R0204
    def testConstructor_004(self):
       """
       Test assignment of warnMidnite attribute, valid value (expression).
@@ -884,6 +886,67 @@ class TestLocalConfig(unittest.TestCase):
       self.validateAddConfig(config)
 
 
+#################
+# TestTool class
+#################
+
+class TestTool(unittest.TestCase):
+
+
+   ################
+   # Setup methods
+   ################
+
+   def setUp(self):
+      try:
+         self.tmpdir = tempfile.mkdtemp()
+         self.resources = findResources(RESOURCES, DATA_DIRS)
+      except Exception, e:
+         self.fail(e)
+
+   def tearDown(self):
+      try:
+         removedir(self.tmpdir)
+      except: pass
+
+
+   ##################
+   # Utility methods
+   ##################
+
+   def extractTar(self, tarname):
+      """Extracts a tarfile with a particular name."""
+      extractTar(self.tmpdir, self.resources['%s.tar.gz' % tarname])
+
+   def buildPath(self, components):
+      """Builds a complete search path from a list of components."""
+      components.insert(0, self.tmpdir)
+      return buildPath(components)
+
+
+   ###########################
+   # Test _checkSourceFiles()
+   ###########################
+
+   def testCheckSourceFiles_001(self):
+      """
+      Test _checkSourceFiles() where some files have an invalid encoding.
+      """
+      self.extractTar("tree13")
+      sourceDir = self.buildPath(["tree13", ])
+      sourceFiles = _buildSourceFiles(sourceDir)
+      self.failUnlessRaises(ValueError, _checkSourceFiles, sourceDir=sourceDir, sourceFiles=sourceFiles)
+
+   def testFileEncoding_002(self):
+      """
+      Test _checkSourceFiles() where all files have a valid encoding.
+      """
+      self.extractTar("tree4")
+      sourceDir = self.buildPath(["tree4", "dir006", ])
+      sourceFiles = _buildSourceFiles(sourceDir)
+      _checkSourceFiles(sourceDir=sourceDir, sourceFiles=sourceFiles)
+
+
 #######################################################################
 # Suite definition
 #######################################################################
@@ -894,6 +957,7 @@ def suite():
    return unittest.TestSuite((
                               unittest.makeSuite(TestAmazonS3Config, 'test'),
                               unittest.makeSuite(TestLocalConfig, 'test'),
+                              unittest.makeSuite(TestTool, 'test'),
                             ))
 
 
