@@ -26,9 +26,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: encrypttests.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Tests encrypt extension functionality.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -68,7 +67,7 @@ Testing XML Extraction
    is extract a node, build some XML from it, and then feed that XML back into
    another object's constructor.  If that parse process succeeds and the old
    object is equal to the new object, we assume that the extract was
-   successful.  
+   successful.
 
    It would arguably be better if we could do a completely independent check -
    but implementing that check would be equivalent to re-implementing all of
@@ -87,9 +86,9 @@ Full vs. Reduced Tests
    want to run all of the tests, set ENCRYPTTESTS_FULL to "Y" in the environment.
 
    In this module, the primary dependency is that for some tests, GPG must have
-   access to the public key for "Kenneth J. Pronovici".  There is also an
-   assumption that GPG does I{not} have access to a public key for anyone named
-   "Bogus J. User" (so we can test failure scenarios).  
+   access to the public key EFD75934.  There is also an assumption that GPG
+   does I{not} have access to a public key for anyone named "Bogus J. User" (so
+   we can test failure scenarios).
 
 @author Kenneth J. Pronovici <pronovic@ieee.org>
 """
@@ -117,11 +116,11 @@ from CedarBackup2.extend.encrypt import _encryptFileWithGpg, _encryptFile, _encr
 #######################################################################
 
 DATA_DIRS = [ "./data", "./testcase/data", ]
-RESOURCES = [ "encrypt.conf.1", "encrypt.conf.2", "tree1.tar.gz", "tree2.tar.gz", 
+RESOURCES = [ "encrypt.conf.1", "encrypt.conf.2", "tree1.tar.gz", "tree2.tar.gz",
               "tree8.tar.gz", "tree15.tar.gz", "tree16.tar.gz", "tree17.tar.gz",
               "tree18.tar.gz", "tree19.tar.gz", "tree20.tar.gz", ]
 
-VALID_GPG_RECIPIENT = "Kenneth J. Pronovici"
+VALID_GPG_RECIPIENT = "EFD75934"
 INVALID_GPG_RECIPIENT = "Bogus J. User"
 
 INVALID_PATH = "bogus"  # This path name should never exist
@@ -510,7 +509,7 @@ class TestLocalConfig(unittest.TestCase):
 
 
    ######################
-   # Test validate logic 
+   # Test validate logic
    ######################
 
    def testValidate_001(self):
@@ -1217,18 +1216,19 @@ class TestFunctions(unittest.TestCase):
 # Suite definition
 #######################################################################
 
+# pylint: disable=C0330
 def suite():
    """Returns a suite containing all the test cases in this module."""
    if runAllTests():
       return unittest.TestSuite((
-                                 unittest.makeSuite(TestEncryptConfig, 'test'), 
-                                 unittest.makeSuite(TestLocalConfig, 'test'), 
-                                 unittest.makeSuite(TestFunctions, 'test'), 
+                                 unittest.makeSuite(TestEncryptConfig, 'test'),
+                                 unittest.makeSuite(TestLocalConfig, 'test'),
+                                 unittest.makeSuite(TestFunctions, 'test'),
                                ))
    else:
       return unittest.TestSuite((
-                                 unittest.makeSuite(TestEncryptConfig, 'test'), 
-                                 unittest.makeSuite(TestLocalConfig, 'test'), 
+                                 unittest.makeSuite(TestEncryptConfig, 'test'),
+                                 unittest.makeSuite(TestLocalConfig, 'test'),
                                ))
 
 
