@@ -170,17 +170,32 @@ def main():
       print "tree, or properly set the PYTHONPATH enviroment variable."
       return 1
 
-   # Set up logging to discard everything
-   devnull = nullDevice()
-   handler = logging.FileHandler(filename=devnull)
-   handler.setLevel(logging.NOTSET)
-   logger = logging.getLogger("CedarBackup2")
-   logger.setLevel(logging.NOTSET)
-   logger.addHandler(handler)
-
    # Get a list of program arguments
    args = sys.argv[1:]
 
+   # Set verbosity for the test runner
+   if "verbose" in args:
+      verbosity = 2   # prints each test name
+      args.remove("verbose")
+   else:
+      verbosity = 1   # prints a . for each test
+
+   # Set up logging, where "debug" sends all output to stderr
+   if "debug" in args:
+      handler = logging.StreamHandler(sys.stdout)
+      handler.setLevel(logging.DEBUG)
+      logger = logging.getLogger("CedarBackup2")
+      logger.setLevel(logging.DEBUG)
+      logger.addHandler(handler)
+      args.remove("debug")
+   else:
+      devnull = nullDevice()
+      handler = logging.FileHandler(filename=devnull)
+      handler.setLevel(logging.NOTSET)
+      logger = logging.getLogger("CedarBackup2")
+      logger.setLevel(logging.NOTSET)
+      logger.addHandler(handler)
+
    # Set flags in the environment to control tests
    if "full" in args:
       full = True
@@ -233,7 +248,7 @@ def main():
    # Create and run the test suite
    print ""
    suite = unittest.TestSuite(unittests.values())
-   suiteResult = unittest.TextTestRunner(verbosity=1).run(suite)
+   suiteResult = unittest.TextTestRunner(verbosity=verbosity).run(suite)
    print ""
    if not suiteResult.wasSuccessful():
       return 1
